The whole of AQA Biology Paper 1 in only 63 minutes!! GCSE 9-1 Science revision

Science and Maths by Primrose Kitten

The whole of AQA Biology Paper 1 in only 63 minutes!! GCSE 9-1 Science revision

These videos are a revision summary for your 9-1 GCSE science, covering biology, chemistry and physics. To get all the quick-fire questions, Knowledge checklists, key words, equations and units sheets and 190 pages of FREE awesomeness head to my website and download your revision guide https://www.primrosekitten.com/collections Amazon will kindly print it off for you http://amzn.to/2kw8DGb or you can treat yourself to the extended version, http://amzn.to/2g1OdTN with another 100 pages of science questions. These are all available over on TuitionKit http://bit.ly/2yYIxxG where you can schedule your revision videos with a timetable that fits in with your life.
AQA Biology Playlist https://www.youtube.com/playlist?list=PL7O6CcKg0HaGnykp12D8yVee_SEQdaEHH
AQA Chemistry Playlist https://www.youtube.com/playlist?list=PL7O6CcKg0HaGhn5E_LwNPH69bagsYQaJs
AQA Physics Playlist https://www.youtube.com/playlist?list=PL7O6CcKg0HaFYC_J92AxS1pfepJJK8kxt
GCSE Maths in only 2 hours https://youtu.be/dYPwEyeyPLA
AQA P1 in only 40 minutes https://youtu.be/xtw-Z0nllA4
The whole of AQA P2 in only47 minutes https://youtu.be/X1aMXCr75Kw
I want to help you achieve the grades you (and I) know you are capable of; these grades are the stepping stone to your future. Even if you don't want to study science or maths further, the grades you get now will open doors in the future.
TuitionKit allows you to schedule your revision videos, mine and loads of other great YouTubers! http://bit.ly/2yYIxxG
To help you get even better grades I’ve written a lot of e-books, packed full of loads of awesome questions to help you study. Because the best thing you can to is practice. Visit my website for e-books, flashcards and extension questions https://www.primrosekitten.com
My exam predictions are just GUESSES!! I don't have any insider knowledge just years of looking at exam papers. Use this as a starting point, but revise EVERYTHING fully. The best way to revise is to get your hands on the past papers and marks schemes (freely available on the exam board website) and look at what questions have been asked and how to answer them. I have lots of notes and exam papers on here to help you.
Disclaimer; You should not carry out any of these practical’s without carrying out a full risk assessment of your own first. Just watching these video will not guarantee to get you a good grade, you’ll also need hard work, this is not a quick fix. I am human and I make mistakes, please point out any that you find and there is no need to follow that with a load of abuse.
Some of the links in here are affiliate links, where is get a small percentage of any money spent, if you like my channel and want to support my work, clicking these is an easy way to do it.
The 'whole of topic in xxx minutes' videos DO NOT comprehensively cover everything you need to know for your exams. it would be impossible to cover 2 years of teaching in under 45 minutes. These should NOT be your only source of revision https://youtu.be/K6d4oOq-pmU xoxox
PhET Interactive Simulations
University of Colorado Boulder
https://phet.colorado.edu
Music; Something Elated by Broke For Free. From the Free Music Archive, CC BY
Images from; Classroom Core (TpT), Hidesy Clipart (TpT), The Cher Room (TpT), The Triple Point (TpT), Ninja Woman (TpT), The Painted Crew (TpT) Shutterstock

15/01/2018